@@ -1,5 +1,5 @@
 alr <-
-function(xx, j = NULL, ifclose = FALSE)
+function(xx, j = NULL, ifclose = FALSE, ifwarn = TRUE)
 {
      # Function to compute arithmetic log-ratios of a data matrix in order
      # to 'open' it; the j-th element is used as the divisor and the column
@@ -11,12 +11,14 @@ function(xx, j = NULL, ifclose = FALSE)
      # required to convert any zero values or other numeric codes representing 
      # blanks to NAs.
      #
-     if(!is.matrix(xx)) stop(deparse(substitute(xx)), " is not a Matix\n")
-     if(is.null(j)) stop("The divisor must be specified\n")
-     p <- length(xx[1, ])
-     if(j > p) stop("j cannot be >", p, "\n")
+     if(!is.matrix(xx)) stop("  ", deparse(substitute(xx)), " is not a Matrix")
+     # Remove any rows containing NAs
      temp.x <- remove.na(xx)
      x <- temp.x$x
+     p <- temp.x$m
+     if(ifwarn) cat("  ** Are the data all in the same measurement units? **\n" )
+     if(is.null(j)) stop("  ** The divisor must be specified **")
+     if(j > p) stop("j cannot be >", p)
      if(ifclose) x <- 100 * sweep(x, 1, rowSums(x), "/")
      x <- log(x)
      x <- sweep(x, 1, x[, j], "-")
