@@ -1,6 +1,6 @@
 inset.exporter <-
 function(x, xlab = deparse(substitute(x)), log = FALSE, xlim = NULL, nclass = NULL, ifnright = TRUE,
-     file = NULL, gtype = "wmf" , ...)
+     file = NULL, table.cex = 0.7, gtype = "wmf" , ...)
 {
      # Wrapper to save the graphics output from a run of inset.
      #
@@ -17,7 +17,8 @@ function(x, xlab = deparse(substitute(x)), log = FALSE, xlim = NULL, nclass = NU
      ##
      if(is.null(file)) stop("\n  Must supply file name for file, e.g., \"c:\\temp\\file\"\n")
      filename <- paste(file, "_", deparse(substitute(x)) ,sep = "")
-     inset(x, xlab = xlab, log = log, xlim = xlim, nclass = nclass, ifnright = ifnright, ...)
+     inset(x, xlab = xlab, log = log, xlim = xlim, nclass = nclass, ifnright = ifnright,
+         table.cex = table.cex, ...)
      savePlot(file = filename, type = gtype)
      invisible()
 }
