@@ -1,8 +1,9 @@
 xyplot.z <-
-function(xx, yy, zz, p = 1, sfact = 1, zmin = NA, zmax = NA, log = NULL, 
+function(xx, yy, zz, p = 0.5, sfact = 2.5, zmin = NA, zmax = NA, log = NULL, 
      xlim = NULL, ylim = NULL, xlab = deparse(substitute(xx)), 
-     ylab = deparse(substitute(yy)), zlab = deparse(substitute(zz)), 
-     main = "", iflgnd = FALSE, symcolr = 1, cex = 0.8, ...)
+     ylab = deparse(substitute(yy)), zlab = deparse(substitute(zz)), main = "",
+     symcolr = 1, ifparams = FALSE, iflgnd = FALSE,
+     title = deparse(substitute(zz)), ...)
 {
      # Function to plot a third variable, zz, as increasing sized circles in
      # the space of a x-y plot.  The rate of increase of the diameter in
@@ -13,6 +14,8 @@ function(xx, yy, zz, p = 1, sfact = 1, zmin = NA, zmax = NA, log = NULL,
      # results in the symbol sizes being truncated at those levels, forcing all
      # lower or higher values than those specified by the provided values to be
      # plotted as same sized circles.  Use parameter fg to alter symbol colour.
+     # Optionally a legend may be added to the plot, and optionally the symbol
+     # plotting parameters may also be added.
      #
      # NOTE: Prior to using this function the data frame/matrix containing the
      # x, y, and zz data must be run through ltdl.fix.df to convert any <dl -ve
@@ -31,16 +34,28 @@ function(xx, yy, zz, p = 1, sfact = 1, zmin = NA, zmax = NA, log = NULL,
              banner <- ""
          else banner <- paste("Proportional Symbol Plot for", zlab)
      else banner <- main
+     z.min <- min(z)
+     z.max <- max(z)
      zrange <- c(zmin, zmax)
      rgz <- syms(z, zrange, p = p)
      if(is.null(log)) log <- ""
      plot(x, y, type = "n", xlab = xlab, ylab = ylab, xlim = xlim, 
          ylim = ylim, log = log, main = banner, ...)
-     symbols(x, y, circles = rgz, inches = sfact * 0.05, add = TRUE,
-         fg = symcolr)
-     if(iflgnd) text(locator(1), paste("Symbols for", zlab,"\np =", p,
-         "& sfact =", sfact, "\nzmin =", zmin, "& zmax =", zmax), 
-         adj = 0.5, cex = cex, ...)
+     symbols(x, y, circles = rgz, inches = sfact * 0.05, fg = symcolr, add = TRUE, ...)
+     if(iflgnd) {
+         if(!is.na(zmax)) z[z > zmax] <- zmax
+         if(!is.na(zmin)) z[z < zmin] <- zmin
+         zval <- quantile(z, prob = c(1.0, 0.75, 0.5, 0.25, 0.0))
+         rgz <- syms(zval, zrange, p = p)
+         zval <- signif(zval, 3)
+         legend(locator(1), pch = rep.int(1, 5), pt.cex = rgz[1:5] * sfact / 0.8,
+             col = rep.int(symcolr, 5), paste(" ", zval[1:5]), cex = 0.8,
+             title = title, ...)
+     }
+     if(ifparams) text(locator(1), paste("p =", signif(p, 3), "& sfact =", sfact,
+         "\nz.max =", signif(z.max, 3), "; zmax =", zmax,
+         "\nz.min =", signif(z.min, 3), "; zmin =", zmin),
+         cex = 0.8, adj =c(0, 1))
      invisible()
 }
 
